import { f as fn } from './generated-dep1.js';

class Main1 {
  constructor () {
    fn();
  }
}

export { Main1 as default };
